[3/3] batman-adv: Convert batadv_dat_addr_t to proper type

Message ID 20180707200121.2684-4-sven@narfation.org (mailing list archive)
State Accepted, archived
Delegated to: Simon Wunderlich
Headers
Series batman-adv: Minor cleanups |

Commit Message

Sven Eckelmann July 7, 2018, 8:01 p.m. UTC
  The #define for batadv_dat_addr_t is doing nothing else than giving u16 a
new typename. But C already has the special keyword "typedef" which is also
better supported by kernel-doc.

Signed-off-by: Sven Eckelmann <sven@narfation.org>
---
 net/batman-adv/types.h | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)
  

Comments

Antonio Quartulli July 8, 2018, 10:45 a.m. UTC | #1
Hi,

On 08/07/18 04:01, Sven Eckelmann wrote:
> The #define for batadv_dat_addr_t is doing nothing else than giving u16 a
> new typename. But C already has the special keyword "typedef" which is also
> better supported by kernel-doc.
> 
> Signed-off-by: Sven Eckelmann <sven@narfation.org>

Acked-by: Antonio Quartulli <a@unstable.cc>
  

Patch

diff --git a/net/batman-adv/types.h b/net/batman-adv/types.h
index 360357f8..343d3048 100644
--- a/net/batman-adv/types.h
+++ b/net/batman-adv/types.h
@@ -43,12 +43,13 @@  struct seq_file;
 #ifdef CONFIG_BATMAN_ADV_DAT
 
 /**
  * batadv_dat_addr_t - it is the type used for all DHT addresses. If it is
  *  changed, BATADV_DAT_ADDR_MAX is changed as well.
  *
  * *Please be careful: batadv_dat_addr_t must be UNSIGNED*
  */
-#define batadv_dat_addr_t u16
+typedef u16 batadv_dat_addr_t;
 
 #endif /* CONFIG_BATMAN_ADV_DAT */
@@ -43,12 +43,13 @@  struct seq_file;
 
 /**
- * batadv_dat_addr_t - it is the type used for all DHT addresses. If it is
- *  changed, BATADV_DAT_ADDR_MAX is changed as well.
+ * typedef batadv_dat_addr_t - type used for all DHT addresses
+ *
+ * If it is changed, BATADV_DAT_ADDR_MAX is changed as well.
  *
  * *Please be careful: batadv_dat_addr_t must be UNSIGNED*